@@ -3,15 +3,16 @@ Main interface for stepfunctions service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.stepfunctions import (
+    from mypy_boto3_stepfunctions import (
         Client,
         GetExecutionHistoryPaginator,
         ListActivitiesPaginator,
         ListExecutionsPaginator,
         ListStateMachinesPaginator,
         SFNClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -22,15 +23,18 @@ Usage::
     list_activities_paginator: ListActivitiesPaginator = client.get_paginator("list_activities")
     list_executions_paginator: ListExecutionsPaginator = client.get_paginator("list_executions")
     list_state_machines_paginator: ListStateMachinesPaginator = client.get_paginator("list_state_machines")
+    ```
 """
-from mypy_boto3_stepfunctions.client import SFNClient as Client, SFNClient
-from mypy_boto3_stepfunctions.paginator import (
+from .client import SFNClient
+from .paginator import (
     GetExecutionHistoryPaginator,
     ListActivitiesPaginator,
     ListExecutionsPaginator,
     ListStateMachinesPaginator,
 )
 
+Client = SFNClient
+
 
 __all__ = (
     "Client",
